@@ -3,6 +3,5 @@ import requests
 def send(unprodata, url):
 
   req = requests.post(url=url, data=unprodata)
-  response = requests.urlopen(req)
 
-  return response.text
\ No newline at end of file
+  return req.text
\ No newline at end of file
